@@ -21,6 +21,10 @@
 
 """
 Acs ERROR CODE module.
+
+Created on 6/15/2015
+
+@author: alex jiang
 """
 
 SDK_INVALID_REGION_ID = 'SDK.InvalidRegionId'
@@ -31,9 +35,4 @@ SDK_UNKNOWN_SERVER_ERROR = 'SDK.UnknownServerError'
 SDK_INVALID_CREDENTIAL = 'SDK.InvalidCredential'
 SDK_INVALID_SESSION_EXPIRATION = 'SDK.InvalidSessionExpiration'
 SDK_GET_SESSION_CREDENTIAL_FAILED = 'SDK.GetSessionCredentialFailed'
-SDK_INVALID_PARAMS = 'SDK.InvalidParams'
-SDK_NOT_SUPPORT = 'SDK.NotSupport'
-SDK_ENDPOINT_RESOLVING_ERROR = 'SDK.EndpointResolvingError'
-SDK_ENDPOINT_TESTABILITY = 'SDK.EndpointTestability'
-SDK_HTTP_ERROR = 'SDK.HttpError'
-SDK_INVALID_PARAMETER = "SDK.InvalidParameter"
+SDK_INVALID_PARAMS = 'SDK.InvalidParams'
\ No newline at end of file
