@@ -17,20 +17,18 @@
 
 # coding=utf-8
 
-
 import hashlib
 import hmac
-
-from aliyunsdkcore.compat import ensure_string
-from aliyunsdkcore.compat import ensure_bytes
-from aliyunsdkcore.compat import b64_encode_bytes
+import base64
 
 
 def get_sign_string(source, secret):
-    source = ensure_bytes(source)
-    secret = ensure_bytes(secret)
+    if isinstance(source, str):
+        source = bytearray(source, "utf-8")
+    if isinstance(secret, str):
+        secret = bytearray(secret, "utf-8")
     h = hmac.new(secret, source, hashlib.sha1)
-    signature = ensure_string(b64_encode_bytes(h.digest()).strip())
+    signature = str(base64.encodebytes(h.digest()).strip(), "utf-8")
     return signature
 
 
@@ -38,7 +36,7 @@ def get_signer_name():
     return "HMAC-SHA1"
 
 
-def get_signer_version():
+def get_singer_version():
     return "1.0"
 
 
