@@ -17,8 +17,11 @@
 
 # coding=utf-8
 
+import urllib.parse
+import urllib.request
+import urllib.response
+
 from aliyunsdkcore.auth.algorithm import sha_hmac1 as mac1
-import urllib
 from aliyunsdkcore.utils import parameter_helper as helper
 
 
@@ -38,8 +41,6 @@ def __refresh_sign_parameters(
         signer=mac1):
     if parameters is None or not isinstance(parameters, dict):
         parameters = dict()
-    if 'Signature'in parameters:
-        del parameters['Signature']
     parameters["Timestamp"] = helper.get_iso_8061_date()
     parameters["SignatureMethod"] = signer.get_signer_name()
     parameters["SignatureType"] = signer.get_signer_type()
@@ -52,17 +53,17 @@ def __refresh_sign_parameters(
 
 
 def __pop_standard_urlencode(query):
-    ret = query.replace('+', '%20')
+    ret = urllib.parse.urlencode(query)
+    ret = ret.replace('+', '%20')
     ret = ret.replace('*', '%2A')
     ret = ret.replace('%7E', '~')
     return ret
 
 
 def __compose_string_to_sign(method, queries):
-    sorted_parameters = sorted(queries.items(), key=lambda queries: queries[0])
-    sorted_query_string = __pop_standard_urlencode(urllib.urlencode(sorted_parameters))
-    canonicalized_query_string = __pop_standard_urlencode(urllib.pathname2url(sorted_query_string))
-    string_to_sign = method + "&%2F&" + canonicalized_query_string
+    sorted_parameters = sorted(list(queries.items()), key=lambda queries: queries[0])
+    string_to_sign = method + "&%2F&" + \
+        urllib.request.pathname2url(__pop_standard_urlencode(sorted_parameters))
     return string_to_sign
 
 
@@ -77,5 +78,5 @@ def get_signed_url(params, ak, secret, accept_format, method, body_params, signe
     string_to_sign = __compose_string_to_sign(method, sign_params)
     signature = __get_signature(string_to_sign, secret, signer)
     url_params['Signature'] = signature
-    url = '/?' + __pop_standard_urlencode(urllib.urlencode(url_params))
+    url = '/?' + __pop_standard_urlencode(url_params)
     return url
