@@ -17,8 +17,8 @@
 
 # coding=utf-8
 
-from aliyunsdkcore.http import format_type
-from aliyunsdkcore.utils import parameter_helper as helper
+from . import format_type
+from ..utils import parameter_helper as helper
 
 
 class HttpRequest:
@@ -27,14 +27,14 @@ class HttpRequest:
     content_length = "Content-Length"
     content_type = "Content-Type"
 
-    def __init__(self, host="", url="/", method=None, headers=None):
+    def __init__(self, host="", url="/", method=None, headers={}):
         self.__host = host
         self.__url = url
         self.__method = method
-        self.__content_type = None
-        self.__content = None
-        self.__encoding = None
-        self.__headers = headers or {}
+        self.__content_type = ""
+        self.__content = ""
+        self.__encoding = ""
+        self.__headers = headers
         self.__body = None
 
     def get_host(self):
@@ -77,32 +77,34 @@ class HttpRequest:
         return self.__content
 
     def get_header_value(self, name):
-        return self.__headers.get(name)
+        return self.__headers[name]
 
     def put_header_parameter(self, key, value):
         if key is not None and value is not None:
             self.__headers[key] = value
 
-    def remove_header_parameter(self, key):
-        if key is not None:
-            if key in self.__headers:
-                self.__headers.pop(key)
+    def md5_sum(self, content):
+        return helper.md5_sum(content)
 
-    def set_content(self, content, encoding, format=format_type.RAW):
-        self.__content = content
+    def set_content(self, content, encoding, format):
         if content is None:
-            self.remove_header_parameter(self.content_md5)
-            self.remove_header_parameter(self.content_type)
-            self.remove_header_parameter(self.content_length)
+            self.__headers.pop(self.content_md5)
+            self.__headers.pop(self.content_length)
+            self.__headers.pop(self.content_type)
             self.__content_type = None
+            self.__content = None
             self.__encoding = None
-        else:
-            str_md5 = helper.md5_sum(content)
-            content_length = len(content)
-            self.__headers[self.content_md5] = str_md5
-            self.__headers[self.content_length] = str(content_length)
-            self.__headers[self.content_type] = format
-            self.__encoding = encoding
+            return
+        str_md5 = self.md5_sum(content)
+        content_length = len(content)
+        content_type = format_type.RAW
+        if format is not None:
+            content_type = format
+        self.__headers[self.content_md5] = str_md5
+        self.__headers[self.content_length] = content_length
+        self.__headers[self.content_type] = content_type
+        self.__content = content
+        self.__encoding = encoding
 
     def get_headers(self):
         return self.__headers
