@@ -21,11 +21,6 @@
 
 import datetime
 import json
-import os
-import sys
-
-parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-sys.path.insert(0, parent_dir)
 
 from ..request import RpcRequest
 from ..http.http_response import HttpResponse
@@ -44,8 +39,8 @@ __location_endpoints = dict()
 __last_cache_clear_time_per_product = dict()
 __location_service_domain = 'location.aliyuncs.com'
 
-
 class DescribeEndpointRequest(RpcRequest):
+
     def __init__(
             self,
             product_name,
@@ -63,7 +58,8 @@ class DescribeEndpointRequest(RpcRequest):
 
 
 class LocationService:
-    def __init__(self, client, timeout=None):
+
+    def __init__(self, client):
         self.__clinetRef = client
         self.__cache = get_location_endpoints()
         self.__service_product_name = LOCATION_SERVICE_PRODUCT_NAME
@@ -73,8 +69,6 @@ class LocationService:
         self.__service_action = LOCATION_SERVICE_DESCRIBE_ENDPOINT_ACTION
         self.__cache_expire_time = LOCATION_CACHE_EXPIRE_TIME
         self.__last_cache_clear_time_per_product = get_last_cache_clear_time_per_product()
-        self._timeout = timeout
-        self._location_access_count = 0
 
     def set_location_service_attr(
             self,
@@ -84,7 +78,7 @@ class LocationService:
         if region is not None:
             self.__service_region = region
 
-        if domain is not None:
+        if domain is not None:            
             self.__service_domain = domain
 
         if product_name is not None:
@@ -96,30 +90,22 @@ class LocationService:
         if domain is None or self.check_endpoint_cache_is_expire(key) is True:
             domain = self.find_product_domain_from_location_service(
                 region_id, service_code, endpoint_type)
-            if domain is None:
-                # set domain as <DomainNotFound> to avoid repeat access to location service
-                # when location fetch miss
-                self.__cache[key] = '<DomainNotFound>'
-            else:
+            if domain is not None:
                 self.__cache[key] = domain
-            self.set_endpoint_cache_update_time(key)
 
-        if domain == '<DomainNotFound>':
-            return None
         return domain
 
-    def set_endpoint_cache_update_time(self, key):
-        now = datetime.datetime.now()
-        self.__last_cache_clear_time_per_product[key] = now
-
     def check_endpoint_cache_is_expire(self, key):
         last_clear_time = self.__last_cache_clear_time_per_product.get(key)
         if last_clear_time is None:
-            return False
+            last_clear_time = datetime.datetime.now()
+            self.__last_cache_clear_time_per_product[key] = last_clear_time
 
         now = datetime.datetime.now()
         elapsed_time = now - last_clear_time
         if now > last_clear_time and elapsed_time.seconds > self.__cache_expire_time:
+            last_clear_time = datetime.datetime.now()
+            self.__last_cache_clear_time_per_product[key] = last_clear_time
             return True
 
         return False
@@ -133,7 +119,6 @@ class LocationService:
                                           region_id,
                                           service_code,
                                           endpoint_type)
-        self._location_access_count += 1
         try:
             content = request.get_content()
             method = request.get_method()
@@ -151,12 +136,11 @@ class LocationService:
                 {} if header is None else header,
                 protocol,
                 content,
-                self.__clinetRef.get_port(),
-                timeout=self._timeout)
+                self.__clinetRef.get_port())
 
             status, header, body = response.get_response_object()
 
-            result = json.loads(body)
+            result = json.loads(body.decode("utf-8"))
             if status == 200:
                 endpoint = result.get('Endpoints').get('Endpoint')
                 if len(endpoint) <= 0:
@@ -169,18 +153,15 @@ class LocationService:
                 # result.get('Message')
                 return None
             elif status >= 500:
-                # return None instead of throw an exception
-                # in case of location service failure
-                # SDK still has to work for robustness
-                return None
+                raise exs.ServerException(
+                    result.get('Code'), result.get('Message'))
             else:
                 raise exs.ClientException(
                     result.get('Code'), result.get('Message'))
         except IOError:
-            # return None instead of throw an exception
-            # in case of location service unreachable,
-            # SDK still has to work for robustness
-            return None
+            raise exs.ClientException(
+                error_code.SDK_SERVER_UNREACHABLE,
+                error_msg.get_msg('SDK_SERVER_UNREACHABLE'))
         except AttributeError:
             raise exs.ClientException(
                 error_code.SDK_INVALID_REQUEST,
