@@ -18,51 +18,34 @@
 # under the License.
 
 # coding=utf-8
-import abc
-from aliyunsdkcore.vendored.six import iterkeys
-from aliyunsdkcore.vendored.six import iteritems
-from aliyunsdkcore.vendored.six import add_metaclass
 
-from aliyunsdkcore.http import protocol_type
-from aliyunsdkcore.http import method_type as mt
-from aliyunsdkcore.http import format_type as ft
-from aliyunsdkcore.auth.composer import rpc_signature_composer as rpc_signer
-from aliyunsdkcore.auth.composer import roa_signature_composer as roa_signer
-from aliyunsdkcore.utils.parameter_helper import md5_sum
-from aliyunsdkcore.auth.algorithm import sha_hmac1
+from .http import protocol_type
+from .http import method_type
+from .http import format_type
+from .auth.composer import rpc_signature_composer as rpc_signer
+from .auth.composer import roa_signature_composer as roa_signer
+from .auth.composer import oss_signature_composer as oss_signer
+from .auth.algorithm import sha_hmac1
+from .auth.utils import md5_tool
 from aliyunsdkcore.acs_exception import exceptions
 from aliyunsdkcore.acs_exception import error_code
-from aliyunsdkcore.compat import ensure_string
-from aliyunsdkcore.vendored.requests.structures import CaseInsensitiveDict
+
+import abc
 
 """
 Acs request model.
+
+Created on 6/15/2015
+
+@author: alex jiang
 """
 
 STYLE_RPC = 'RPC'
 STYLE_ROA = 'ROA'
-
-_default_protocol_type = protocol_type.HTTP
+STYLE_OSS = 'OSS'
 
 
-def set_default_protocol_type(user_protocol_type):
-    global _default_protocol_type
-
-    if user_protocol_type == protocol_type.HTTP or user_protocol_type == protocol_type.HTTPS:
-        _default_protocol_type = user_protocol_type
-    else:
-        raise exceptions.ClientException(
-            error_code.SDK_INVALID_PARAMS,
-            "Invalid 'protocol_type', should be 'http' or 'https'"
-        )
-
-
-def get_default_protocol_type():
-    return _default_protocol_type
-
-
-@add_metaclass(abc.ABCMeta)
-class AcsRequest:
+class AcsRequest(metaclass=abc.ABCMeta):
     """
     Acs request base class. This class wraps up common parameters for a request.
     """
@@ -72,7 +55,7 @@ class AcsRequest:
                  location_service_code=None,
                  location_endpoint_type='openAPI',
                  accept_format=None,
-                 protocol_type=None,
+                 protocol_type=protocol_type.HTTP,
                  method=None):
         """
 
@@ -89,33 +72,16 @@ class AcsRequest:
         self._product = product
         self._action_name = action_name
         self._protocol_type = protocol_type
-        if self._protocol_type is None:
-            self._protocol_type = _default_protocol_type
-
         self._accept_format = accept_format
         self._params = {}
         self._method = method
         self._header = {}
-        if action_name is not None:
-            self.add_header('x-acs-action', action_name)
-        if version is not None:
-            self.add_header('x-acs-version', version)
         self._body_params = {}
         self._uri_pattern = None
         self._uri_params = None
         self._content = None
         self._location_service_code = location_service_code
         self._location_endpoint_type = location_endpoint_type
-        self.add_header('x-sdk-invoke-type', 'normal')
-        self.endpoint = None
-        self._extra_user_agent = {}
-        self.string_to_sign = ''
-        self._request_connect_timeout = None
-        self._request_read_timeout = None
-        self.request_network = "public"
-        self.product_suffix = ""
-        self.endpoint_map = None
-        self.endpoint_regional = None
 
     def add_query_param(self, k, v):
         self._params[k] = v
@@ -166,11 +132,9 @@ class AcsRequest:
         self._product = product
 
     def set_version(self, version):
-        self._header['x-acs-version'] = version
         self._version = version
 
     def set_action_name(self, action_name):
-        self._header['x-acs-action'] = action_name
         self._action_name = action_name
 
     def set_accept_format(self, accept_format):
@@ -182,9 +146,6 @@ class AcsRequest:
     def set_query_params(self, params):
         self._params = params
 
-    def set_body_params(self, body_params):
-        self._body_params = body_params
-
     def set_content(self, content):
         """
 
@@ -221,21 +182,6 @@ class AcsRequest:
     def set_user_agent(self, agent):
         self.add_header('User-Agent', agent)
 
-    def append_user_agent(self, key, value):
-        self._extra_user_agent.update({key: value})
-
-    def request_user_agent(self):
-        request_user_agent = {}
-        if 'User-Agent' in self.get_headers():
-            request_user_agent.update({
-                'request': self.get_headers().get('User-Agent')
-            })
-
-        else:
-            request_user_agent.update(self._extra_user_agent)
-
-        return CaseInsensitiveDict(request_user_agent)
-
     def set_location_service_code(self, location_service_code):
         self._location_service_code = location_service_code
 
@@ -260,21 +206,6 @@ class AcsRequest:
     def get_signed_header(self, region_id, ak, secret):
         pass
 
-    def set_endpoint(self, endpoint):
-        self.endpoint = endpoint
-
-    def get_connect_timeout(self):
-        return self._request_connect_timeout
-
-    def set_connect_timeout(self, connect_timeout):
-        self._request_connect_timeout = connect_timeout
-
-    def get_read_timeout(self):
-        return self._request_read_timeout
-
-    def set_read_timeout(self, read_timeout):
-        self._request_read_timeout = read_timeout
-
 
 class RpcRequest(AcsRequest):
     """
@@ -300,7 +231,7 @@ class RpcRequest(AcsRequest):
             location_endpoint_type,
             format,
             protocol,
-            mt.GET)
+            method_type.GET)
         self._style = STYLE_RPC
         self._signer = signer
 
@@ -317,27 +248,22 @@ class RpcRequest(AcsRequest):
 
         return req_params
 
-    def get_url(self, region_id, access_key_id, access_key_secret):
-        sign_params = dict(self._get_sign_params())
-        if 'RegionId' not in iterkeys(sign_params):
+    def get_url(self, region_id, ak, secret):
+        sign_params = self._get_sign_params()
+        if 'RegionId' not in list(sign_params.keys()):
             sign_params['RegionId'] = region_id
-        url, string_to_sign = rpc_signer.get_signed_url(
+        url = rpc_signer.get_signed_url(
             sign_params,
-            access_key_id,
-            access_key_secret,
+            ak,
+            secret,
             self.get_accept_format(),
             self.get_method(),
             self.get_body_params(),
             self._signer)
-        self.string_to_sign = string_to_sign
         return url
 
     def get_signed_header(self, region_id=None, ak=None, secret=None):
-        headers = {}
-        for headerKey, headerValue in iteritems(self.get_headers()):
-            if headerKey.startswith("x-acs-") or headerKey.startswith("x-sdk-"):
-                headers[headerKey] = headerValue
-        return headers
+        return {}
 
 
 class RoaRequest(AcsRequest):
@@ -376,12 +302,12 @@ class RoaRequest(AcsRequest):
             action_name,
             location_service_code,
             location_endpoint_type,
-            ft.RAW,
+            format_type.RAW,
             protocol,
             method)
         self._style = STYLE_ROA
         self._method = method
-        if headers is not None:
+        if headers:
             self._header = headers
         self._uri_pattern = uri_pattern
         self._path_params = path_params
@@ -422,24 +348,21 @@ class RoaRequest(AcsRequest):
         :param secret: String
         :return: Dict
         """
-        sign_params = dict(self._get_sign_params())
+        sign_params = self._get_sign_params()
         if self.get_content() is not None:
-            self.add_header(
-                'Content-MD5', md5_sum(self.get_content()))
-        if 'RegionId' not in sign_params.keys():
+            md5_str = md5_tool.get_md5_base64_str(self.get_content())
+            self.add_header('Content-MD5', md5_str)
+        if 'RegionId' not in list(sign_params.keys()):
             sign_params['RegionId'] = region_id
-            self.add_header('x-acs-region-id', str(region_id))
-
-        signed_headers, sign_to_string = roa_signer.get_signature_headers(
+        signed_headers = roa_signer.get_signature_headers(
             sign_params,
             ak,
             secret,
             self.get_accept_format(),
-            self.get_headers().copy(),
+            self.get_headers(),
             self.get_uri_pattern(),
             self.get_path_params(),
             self.get_method())
-        self.string_to_sign = sign_to_string
         return signed_headers
 
     def get_url(self, region_id, ak=None, secret=None):
@@ -448,8 +371,8 @@ class RoaRequest(AcsRequest):
         :param region_id: String
         :return: String
         """
-        sign_params = dict(self.get_query_params())
-        if 'RegionId' not in sign_params.keys():
+        sign_params = self.get_query_params()
+        if region_id not in list(sign_params.keys()):
             sign_params['RegionId'] = region_id
         url = roa_signer.get_url(
             self.get_uri_pattern(),
@@ -458,39 +381,145 @@ class RoaRequest(AcsRequest):
         return url
 
 
-class CommonRequest(AcsRequest):
-    def __init__(self, domain=None, version=None, action_name=None, uri_pattern=None, product=None,
-                 location_endpoint_type='openAPI'):
-        super(CommonRequest, self).__init__(product, version, action_name)
+class OssRequest(AcsRequest):
+    def __init__(
+            self,
+            product,
+            version,
+            action_name,
+            location_service_code,
+            bucket=None,
+            method=None,
+            headers=None,
+            uri_pattern=None,
+            path_params=None,
+            protocol=None):
+        """
 
-        self.request = None
-        self.endpoint = domain
+        :param product: String, mandatory
+        :param version: String, mandatory
+        :param action_name: String, mandatory
+        :param bucket: String
+        :param method: String
+        :param headers: Dict
+        :param uri_pattern: String
+        :param path_params: Dict
+        :param protocol: String
+        :return:
+        """
+        AcsRequest.__init__(
+            self,
+            product,
+            version,
+            action_name,
+            location_service_code,
+            'openAPI',
+            format_type.XML,
+            protocol,
+            method)
+        self.__style = STYLE_OSS
+        self.__bucket = bucket
+        self.__method = method
+        self.__header = headers
+        self.__uri_pattern = uri_pattern
+        self.__path_params = path_params
+
+    def get_style(self):
+        return self.__style
+
+    def get_path_params(self):
+        """
+
+        :return: dict
+        """
+        return self.__path_params
+
+    def set_path_params(self, path_params):
+        self.__path_params = path_params
+
+    def add_path_param(self, k, v):
+        if self.__path_params is None:
+            self.__path_params = {}
+        self.__path_params[k] = v
+
+    def __get_sign_params(self):
+        req_params = self.get_query_params()
+        if req_params is None:
+            req_params = {}
+        req_params['Version'] = self.get_version()
+        req_params['Action'] = self.get_action_name()
+        req_params['Format'] = self.get_accept_format()
+        return req_params
+
+    def get_signed_header(self, region_id, ak, secret, ):
+        """
+        Compose signed headers.
+        :param region_id: String
+        :param ak: String
+        :param secret: String
+        :return:
+        """
+        sign_params = self.get_query_params()
+        if 'RegionId' not in list(sign_params.keys()):
+            sign_params['RegionId'] = region_id
+        signed_headers = oss_signer.get_signature_headers(
+            sign_params,
+            ak,
+            secret,
+            self.get_accept_format(),
+            self.get_headers(),
+            self.get_uri_pattern(),
+            self.get_path_params(),
+            self.get_method(),
+            self.__bucket)
+        return signed_headers
+
+    def get_url(self, region_id, ak=None, secret=None):
+        """
+        Generate request url without domain
+        :param region_id: String
+        :return: String
+        """
+        sign_params = self.get_query_params()
+        if 'RegionId' not in list(sign_params.keys()):
+            sign_params['RegionId'] = region_id
+        url = oss_signer.get_url(
+            sign_params,
+            self.get_uri_pattern(),
+            self.get_path_params())
+        return url
+
+
+class CommonRequest(RpcRequest, RoaRequest):
+    def __init__(self, domain=None, version=None, action_name=None, uri_pattern=None, product=None):
+        RoaRequest.__init__(self, product, version, action_name)
+        RpcRequest.__init__(self, product, version, action_name)
+
+        self._domain = domain
         self._version = version
         self._action_name = action_name
         self._uri_pattern = uri_pattern
         self._product = product
-        self._location_endpoint_type = location_endpoint_type
+        self._location_endpoint_type = 'openAPI',
         self._signer = sha_hmac1
-        self.add_header('x-sdk-invoke-type', 'common')
-        self._path_params = None
-        self._method = "GET"
-
-    def get_path_params(self):
-        return self._path_params
-
-    def set_path_params(self, path_params):
-        self._path_params = path_params
-
-    def add_path_param(self, k, v):
-        if self._path_params is None:
-            self._path_params = {}
-        self._path_params[k] = v
 
     def set_domain(self, domain):
-        self.endpoint = domain
+        self._domain = domain
 
     def get_domain(self):
-        return self.endpoint
+        return self._domain
+
+    def set_version(self, version):
+        self._version = version
+
+    def get_version(self):
+        return self._version
+
+    def set_action_name(self, action_name):
+        self._action_name = action_name
+
+    def get_action_name(self):
+        return self._action_name
 
     def set_uri_pattern(self, uri_pattern):
         self._uri_pattern = uri_pattern
@@ -506,70 +535,31 @@ class CommonRequest(AcsRequest):
 
     def trans_to_acs_request(self):
         if not self._version:
-            raise exceptions.ClientException(
-                error_code.SDK_INVALID_PARAMS,
-                'common params [version] is required, cannot be empty')
+            raise exceptions.ClientException(error_code.SDK_INVALID_PARAMS,
+                                             'common params [version] is required, cannot be empty')
         if not self._action_name and not self._uri_pattern:
-            raise exceptions.ClientException(
-                error_code.SDK_INVALID_PARAMS,
-                'At least one of [action] and [uri_pattern] has a value')
-        if not self.endpoint and not self._product:
-            raise exceptions.ClientException(
-                error_code.SDK_INVALID_PARAMS,
-                'At least one of [domain] and [product_name] has a value')
+            raise exceptions.ClientException(error_code.SDK_INVALID_PARAMS,
+                                             'At least one of [action] and [uri_pattern] has a value')
+        if not self._domain and not self._product:
+            raise exceptions.ClientException(error_code.SDK_INVALID_PARAMS,
+                                             'At least one of [domain] and [product_name] has a value')
 
         if self._uri_pattern:
             self._style = STYLE_ROA
-            self.request = RoaRequest(product=self.get_product(), version=self.get_version(),
-                                      action_name=self.get_action_name(),
-                                      location_endpoint_type=self.get_location_endpoint_type()
-                                      )
-            self.fill_params()
         else:
             self._style = STYLE_RPC
-            self.request = RpcRequest(product=self.get_product(), version=self.get_version(),
-                                      action_name=self.get_action_name(),
-                                      location_endpoint_type=self.get_location_endpoint_type(),
-                                      )
-            self.fill_params()
 
     def get_style(self):
         return self._style
 
     def get_url(self, region_id, ak, secret):
-        return self.request.get_url(region_id, ak, secret)
+        if self._style == STYLE_RPC:
+            return RpcRequest.get_url(self, region_id, ak, secret)
+        else:
+            return RoaRequest.get_url(self, region_id, ak, secret)
 
-    def get_signed_header(self, region_id, access_key_id, access_key_secret):
-        return self.request.get_signed_header(region_id, access_key_id, access_key_secret)
-
-    def fill_params(self):
-
-        self.request.set_uri_pattern(self.get_uri_pattern())
-
-        self.request.set_uri_params(self.get_uri_params())
-
-        if self.get_style() == STYLE_ROA:
-            self.request.set_path_params(self.get_path_params())
-
-        self.request.set_method(self.get_method())
-
-        self.request.set_product(self.get_product())
-
-        self.request.set_version(self.get_version())
-
-        self.request.set_action_name(self.get_action_name())
-
-        self.request.set_accept_format(self.get_accept_format())
-
-        self.request.set_protocol_type(self.get_protocol_type())
-
-        self.request.set_query_params(self.get_query_params())
-
-        self.request.set_content(self.get_content())
-
-        self.request.set_headers(self.get_headers())
-
-        self.request.set_location_service_code(
-            self.get_location_service_code())
-
-        self.request.set_body_params(self.get_body_params())
+    def get_signed_header(self, region_id, ak, secret):
+        if self._style == STYLE_RPC:
+            return RpcRequest.get_signed_header(self, region_id, ak, secret)
+        else:
+            return RoaRequest.get_signed_header(self, region_id, ak, secret)
